@@ -59,7 +59,7 @@ content <- function(x, as = NULL, type = NULL, encoding = NULL, ...) {
   stopifnot(is.response(x))
 
   type <- type %||% x$headers[["Content-Type"]] %||%
-    mime::guess_type(x$url, empty = NULL)
+    mime::guess_type(x$url, empty = "application/octet-stream")
 
   as <- as %||% parseability(type)
   as <- match.arg(as, c("raw", "text", "parsed"))
