@@ -11,5 +11,8 @@
 }
 
 release_questions <- function() {
-  c("Have you run all the OAuth demos?")
+  c(
+    "Have you run all the OAuth demos?",
+    "Is inst/cacert.pem up to date?"
+  )
 }
